==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/architecture/statement/impl/GenerateSetImpl.java <==
package io.ciera.tool.sql.architecture.statement.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.tool.sql.architecture.expression.ExpressionSet;
import io.ciera.tool.sql.architecture.expression.impl.ExpressionSetImpl;
import io.ciera.tool.sql.architecture.statement.Generate;
import io.ciera.tool.sql.architecture.statement.GenerateSet;
import io.ciera.tool.sql.architecture.statement.StatementSet;
import io.ciera.tool.sql.architecture.statement.impl.StatementSetImpl;

import java.util.Arrays;
import java.util.List;


public class GenerateSetImpl extends InstanceSet<GenerateSet,Generate> implements GenerateSet {

    // attributes
    @Override
    public void setStatement_number( String ref_statement_number ) throws XtumlException {
        for ( Generate generate : this ) generate.setStatement_number( ref_statement_number );
    }
    @Override
    public void setEvt_expression_number( String ref_evt_expression_number ) throws XtumlException {
        for ( Generate generate : this ) generate.setEvt_expression_number( ref_evt_expression_number );
    }
    @Override
    public void setParent_name( String ref_parent_name ) throws XtumlException {
        for ( Generate generate : this ) generate.setParent_name( ref_parent_name );
    }
    @Override
    public void setParent_package( String ref_parent_package ) throws XtumlException {
        for ( Generate generate : this ) generate.setParent_package( ref_parent_package );
    }
    @Override
    public void setBody_name( String ref_body_name ) throws XtumlException {
        for ( Generate generate : this ) generate.setBody_name( ref_body_name );
    }
    @Override
    public void setBlock_number( String ref_block_number ) throws XtumlException {
        for ( Generate generate : this ) generate.setBlock_number( ref_block_number );
    }


    // selections
    @Override
    public StatementSet R451_is_a_Statement() throws XtumlException {
        StatementSet statementset = new StatementSetImpl();
        for ( Generate generate : this ) statementset.add( generate.R451_is_a_Statement() );
        return statementset;
    }
    @Override
    public ExpressionSet R486_generates_Expression() throws XtumlException {
        ExpressionSet expressionset = new ExpressionSetImpl();
        for ( Generate generate : this ) expressionset.add( generate.R486_generates_Expression() );
        return expressionset;
    }


    @Override
    public Generate nullElement() {
        return GenerateImpl.EMPTY_GENERATE;
    }

    @Override
    public GenerateSet emptySet() {
      return new GenerateSetImpl();
    }

    @Override
    public GenerateSet value() {
        return this;
    }

    @Override
    public List<Generate> elements() {
        return Arrays.asList(toArray(new Generate[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/architecture/statement/impl/GenerateSetImpl.java <==
package io.ciera.tool.sql.architecture.statement.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.tool.sql.architecture.expression.ExpressionSet;
import io.ciera.tool.sql.architecture.expression.impl.ExpressionSetImpl;
import io.ciera.tool.sql.architecture.statement.Generate;
import io.ciera.tool.sql.architecture.statement.GenerateSet;
import io.ciera.tool.sql.architecture.statement.StatementSet;
import io.ciera.tool.sql.architecture.statement.impl.StatementSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class GenerateSetImpl extends InstanceSet<GenerateSet,Generate> implements GenerateSet {

    public GenerateSetImpl() {
    }

    public GenerateSetImpl(Comparator<? super Generate> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setStatement_number( String ref_statement_number ) throws XtumlException {
        for ( Generate generate : this ) generate.setStatement_number( ref_statement_number );
    }
    @Override
    public void setParent_name( String ref_parent_name ) throws XtumlException {
        for ( Generate generate : this ) generate.setParent_name( ref_parent_name );
    }
    @Override
    public void setBlock_number( String ref_block_number ) throws XtumlException {
        for ( Generate generate : this ) generate.setBlock_number( ref_block_number );
    }
    @Override
    public void setParent_package( String ref_parent_package ) throws XtumlException {
        for ( Generate generate : this ) generate.setParent_package( ref_parent_package );
    }
    @Override
    public void setEvt_expression_number( String ref_evt_expression_number ) throws XtumlException {
        for ( Generate generate : this ) generate.setEvt_expression_number( ref_evt_expression_number );
    }
    @Override
    public void setBody_name( String ref_body_name ) throws XtumlException {
        for ( Generate generate : this ) generate.setBody_name( ref_body_name );
    }


    // selections
    @Override
    public StatementSet R451_is_a_Statement() throws XtumlException {
        StatementSet statementset = new StatementSetImpl();
        for ( Generate generate : this ) statementset.add( generate.R451_is_a_Statement() );
        return statementset;
    }
    @Override
    public ExpressionSet R486_generates_Expression() throws XtumlException {
        ExpressionSet expressionset = new ExpressionSetImpl();
        for ( Generate generate : this ) expressionset.add( generate.R486_generates_Expression() );
        return expressionset;
    }


    @Override
    public Generate nullElement() {
        return GenerateImpl.EMPTY_GENERATE;
    }

    @Override
    public GenerateSet emptySet() {
      return new GenerateSetImpl();
    }

    @Override
    public GenerateSet emptySet(Comparator<? super Generate> comp) {
      return new GenerateSetImpl(comp);
    }

    @Override
    public GenerateSet value() {
        return this;
    }

    @Override
    public List<Generate> elements() {
        return Arrays.asList(toArray(new Generate[0]));
    }

}
